#R Codes for the Long-term variation of the diversity indices in the Lake Kasumigaura (Figure S1) and Western English Channel (Figure S2)

library(ggplot2)  # for creating graphs
library(gridExtra) # for arranging plots



WD <- getwd()
#load ST9 and L4 data and selected the RUEs 
dat_st9 <- read.csv(paste(WD,'/Data/','ST9_Diversity_RUE.csv',sep = ""))
dat_l4 <- read.csv(paste(WD,'/Data/','L4_Diversity_RUE.csv',sep = ""))

dat_st9$Date = as.Date(dat_st9$Date)
dat_l4$Date =  as.Date(dat_l4$Date)
#na.rm=TRUE

#limits = as.Date(c('1984-10-07','2013-04-07'))
#geom_point() point
#geom_line()

# plotting for Figure S1 Long-term variation of the functional diversity (FAD2, FDc, and FRic) and Shannon diversity index (H) in the Lake Kasumigaura.
st9.FAD2 = ggplot(data =dat_st9 , aes(x=Date, y=FAD2)) + geom_point() + geom_line() + ylab("FAD2")+xlab("") + theme_bw()
st9.FDc = ggplot(data = dat_st9, aes(Date, FDc)) +  geom_point() + geom_line() + ylab("FDc") +xlab("")+ theme_bw()
st9.FRic = ggplot(data = dat_st9, aes(Date, FRic)) +  geom_point() + geom_line() + ylab("FRic") + xlab("")+theme_bw()
st9.H = ggplot(data = dat_st9, aes(Date, H)) +  geom_point() + geom_line() + ylab("H") + theme_bw()

a1 = st9.FAD2 + scale_x_date(date_breaks = "5 year", date_minor_breaks = "1 year", date_labels = "%b %Y", limits = as.Date(c('1984-10-07','2013-06-07')) )
a2 = st9.FDc + scale_x_date(date_breaks = "5 year", date_minor_breaks = "1 year", date_labels = "%b %Y", limits = as.Date(c('1984-10-07','2013-06-07')) )
a3 = st9.FRic + scale_x_date(date_breaks = "5 year", date_minor_breaks = "1 year", date_labels = "%b %Y", limits = as.Date(c('1984-10-07','2013-06-07')) )
a4 = st9.H + scale_x_date(date_breaks = "5 year", date_minor_breaks = "1 year", date_labels = "%b %Y", limits = as.Date(c('1984-10-07','2013-06-07')) )

grid.arrange(a1,a2,a3,a4, ncol = 1)

# end for Figure S1


# Plotting for Figure S2 Long-term variation of the functional diversity (FAD2, FDc, and FRic) and Shannon diversity index (H) in the Western English Channel.
l4.FAD2 = ggplot(data =dat_l4 , aes(x=Date, y=FAD2)) + geom_point() + geom_line() + ylab("FAD2")+xlab("") + theme_bw()
l4.FDc = ggplot(data = dat_l4, aes(Date, FDc)) +  geom_point() +geom_line() + ylab("FDc")+xlab("") + theme_bw()
l4.FRic = ggplot(data = dat_l4, aes(Date, FRic)) +  geom_point() + geom_line() + ylab("FRic")+xlab("") + theme_bw()
l4.H = ggplot(data = dat_l4, aes(Date, H)) +  geom_point() + geom_line() + ylab("H") + theme_bw()

b1 = l4.FAD2 + scale_x_date(date_breaks = "5 year", date_minor_breaks = "1 year", date_labels = "%b %Y")
b2 = l4.FDc + scale_x_date(date_breaks = "5 year", date_minor_breaks = "1 year", date_labels = "%b %Y")
b3 = l4.FRic + scale_x_date(date_breaks = "5 year", date_minor_breaks = "1 year", date_labels = "%b %Y")
b4 = l4.H + scale_x_date(date_breaks = "5 year", date_minor_breaks = "1 year", date_labels = "%b %Y")
 
grid.arrange(b1,b2,b3,b4, ncol = 1)

#End for Figure S2
