#Codes for Figure S3
#Determining the embedding dimension (E) by false nearest neighbors method

#load the library
library('dplyr')
library('tidyr')
library("fractal")

#get the absolute filepath for this R code
WD <- getwd()

#load ST9 and L4 data and selected the RUEs 
dat_st9 <- read.csv(paste(WD,'/Data/','ST9_Diversity_RUE.csv',sep = ""))
dat_st9$date = as.POSIXlt(dat_st9$Date, tz = "GMT")
fnn.dat.st9=dat_st9[,c(9,7,8)]

dat_L4 <- read.csv(paste(WD,'/Data/','L4_Diversity_RUE.csv',sep = ""))
dat_L4$date = as.POSIXlt(dat_L4$Date, tz = "GMT")
fnn.dat.L4=dat_L4[,c(10,7:9)]


#testing the optimal E for each RUE 
fnn_results = NULL

#for ST9
for (i in 2:3) {
    rue <- fnn.dat.st9[i]
    x <- FNN(rue[!is.na(rue)], dimension=24, rtol=10, atol=2, olag=1)
    E <- 1:24
    rtol <- x[seq(1,72,by=3)] 
    
    fnn_results <- fnn_results %>% bind_rows(data.frame(Site="ST9",Variable=names(fnn.dat.st9[i]),E = E,  rtol=rtol))
}


#for L4
for (i in 2:4) {
    rue <- fnn.dat.L4[i]
    x <- FNN(rue[!is.na(rue)], dimension=24, rtol=10, atol=2, olag=1)
    E <- 1:24
    rtol <- x[seq(1,72,by=3)] 
    
    fnn_results <- fnn_results %>% bind_rows(data.frame(Site="L4",Variable=names(fnn.dat.L4[i]),E = E,  rtol=rtol))
}

#save results as csv
#write.csv(fnn_results , "fnn_test.csv")


#plot the results 
st9_N <- fnn_results %>%
filter(Site == 'ST9') %>% 
filter(Variable == 'RUE_DIN')

st9_P <- fnn_results %>%
filter(Site == 'ST9') %>% 
filter(Variable == 'RUE_PO4P')

L4_N <- fnn_results %>%
filter(Site == 'L4') %>% 
filter(Variable == 'RUE_DIN')

L4_P <- fnn_results %>%
filter(Site == 'L4') %>% 
filter(Variable == 'RUE_PO4P')

L4_Si <- fnn_results %>%
filter(Site == 'L4') %>% 
filter(Variable == 'RUE_DSi')


X11(12, 8)
par(mfrow=c(2,3))
par(cex = 1.1)
with(st9_N, plot(E, rtol, type="o",xlab="Embedding dimension (E)", ylab = "% of false nearest neighbours" ) +  abline(v=5,lty=2,col='red') )
with(st9_P, plot(E, rtol, type="o",xlab="Embedding dimension (E)", ylab = "% of false nearest neighbours" ) +  abline(v=7,lty=2,col='red') )
frame()

with(L4_N, plot(E, rtol, type="o",xlab="Embedding dimension (E)", ylab = "% of false nearest neighbours" ) +  abline(v=5,lty=2,col='red') )
with(L4_P, plot(E, rtol, type="o",xlab="Embedding dimension (E)", ylab = "% of false nearest neighbours" ) +  abline(v=3,lty=2,col='red') )
with(L4_Si, plot(E, rtol, type="o",xlab="Embedding dimension (E)", ylab = "% of false nearest neighbours" ) +  abline(v=5,lty=2,col='red') )



