# Codes for S-maps
# Fig. 3 Results of scenario exploration showing the effect of changes in diversity indices (Z) on resource use efficiency (RUE) in the Lake Kasumigaura ST9. 
# Fig. 4 Results of scenario exploration showing the effect of changes in diversity indices (Z) on resource use efficiency (RUE) in the Western English Channel L4. 

library('rEDM')
library('dplyr')
library('tidyr')
library('pracma')

make_block <- function(data,cols,delays,lib=c(1,NROW(data))){
	lib <- matrix(lib,ncol = 2)
	data <- as.matrix(data)
	ncol <- length(cols)
	nrow <- dim(data)[1]
	block <- array(NA,dim = c(nrow,ncol))
	colnames(block) <- 1:ncol
	
	for (i in 1:ncol){
		I <- 1:nrow
		I_delay <- intersect(I,I+delays[i])
		block[I_delay-delays[i],i] <- data[I_delay,cols[i]]
		if (delays[i] < 0){
			# remove data points that fall at start of lib segments
			block[lib[,1] - (0:(delays[i]+1)),i] <- NA
			colnames(block)[i] <- paste(colnames(data)[cols[i]],'_t-',abs(delays[i]),sep="")
			} else if (delays[i] > 0) {
			# remove data points that fall at end of lib segments
			block[lib[,2] - (0:(delays[i]-1)),i] <- NA   #block[lib[,2] - (0:(delays[i]+1)),i] <- NA edit by YL
			colnames(block)[i] <- paste(colnames(data)[cols[i]],'_t+',abs(delays[i]),sep="")
			} else {
			colnames(block)[i] <- paste(colnames(data)[cols[i]],'_t',sep="")
		}
	}
	return(block)
}

make_pred_nozero <- function(time_series,E){
	I_zero_strings <- which(time_series==0)
	I_zero_strings <- Reduce(intersect, lapply((0:E),function(offset) I_zero_strings-offset))
	I_zero_strings <- c(0,I_zero_strings,NROW(df.in)) # for convenience in next step
	N_zero_strings <- length(I_zero_strings)
	lib_nozeroes <- cbind(I_zero_strings[1:(N_zero_strings-1)]+1,I_zero_strings[2:(N_zero_strings)]-1)
	lib_out <- lib_nozeroes[which(lib_nozeroes[,2] > lib_nozeroes[,1]),]
	return(lib_out)
	}

#Set working directory
mainDir <- getwd()
subDir <- 'SE-Test' 
 if (file.exists(subDir)){
    setwd(file.path(mainDir, subDir))
} else {
    dir.create(file.path(mainDir, subDir))
    setwd(file.path(mainDir, subDir))
}


#Definle input parameters

#reload the best E for ST9 and L4
E.ST9 <- c(5,5,5,5,7,7,7,7)
E.L4 <- c(5,5,5,5,3,3,3,3,5,5,5,5)
theta.test.range <- seq(0, 10, 0.1)
tp.SE <- 1
norm_method = 'scale'    # scaled data with zscore method was used in the manuscript
# define the disturbance
dDiversity <- 0.05



# load data and run analysis for ST9 
site = 'ST9'     #ST9, L4
dat_st9 <- read.csv(paste(mainDir,'/Data/','ST9_Diversity_RUE.csv',sep = "")) # read in plot-level data with raw vars
dat_st9$date = as.POSIXlt(dat_st9$Date, tz = "GMT")
# selecting FAD2, FDc, FRic, H, and RUEs
ye.dat.st9=dat_st9[,c(9,2:4,6:8)]

ye.dat = ye.dat.st9
testvb=colnames(ye.dat[c(2:7)])
nvb=length(testvb)
cause_name = testvb[c(1:4)]
effect_name = testvb[c(5:6)]

indmat =matrix(0,length(cause_name)*length(effect_name),2);colnames(indmat)=c('Effect','Cause')
indmat[,1]=rep(effect_name,each=length(cause_name))
indmat[,2]=rep(cause_name,length(effect_name))


# Scenario Exploration
# Parameters
#ccm_results = NULL

for(i in 1:nrow(indmat)){
 
 #for each RUE
  df.in = data.frame (date = ye.dat$date, RUE = ye.dat[,indmat[i,1]], Diversity = ye.dat[,indmat[i,2]])

  #normilize the input
  df.in.SE = data.frame (date = ye.dat$date, RUE = scale(ye.dat[,indmat[i,1]]), Diversity = scale(ye.dat[,indmat[i,2]])) 
  
	idx <- is.finite(df.in.SE$RUE) & is.finite(df.in.SE$Diversity)
	df.in.SE <- df.in.SE[idx,]
  df.in.non_zero <- df.in[idx,]

if (site == 'ST9'){
E.SE = E.ST9[i] } else {
E.SE = E.L4[i]
}

  block.SE <- make_block(df.in.SE[,c('RUE','Diversity')],c(rep(1,E.SE),2),c(tp=tp.SE,0:-(E.SE-2),0)	) %>%
	as.data.frame()
#	block.SE <- data.frame(time = df.in.SE$date, block.SE)

  # test the best theta
        smapT.test <- block_lnlp(block.SE,
                               method = "s-map",
                               num_neighbors = 0,
                               save_smap_coefficients = F,
                               target_column = 1,
                               columns = 1+(1:E.SE),
                               first_column_time = F,
                               theta = theta.test.range,
                               exclusion_radius = 0,
                               silent = T)

       theta.SE <- smapT.test[which.max(smapT.test$rho), "theta"]


	# make predictions with diversity no change
	pred.SE <- c(1,NROW(block.SE))
	lib.SE <- pred.SE + NROW(block.SE)
	block.temp0 <- block.SE %>%
	  mutate(Diversity_t = Diversity_t) %>%
	  bind_rows(block.SE)

	out0 <- block_lnlp(block=block.temp0,
	                   lib = lib.SE,
	                   pred = pred.SE,
	                   method = 's-map',
	                   tp = 0,
	                   #num_neighbors = 0,
	                   columns = 1+(1:E.SE),
	                   target_column = 1,
	                   stats_only = FALSE,
	                   first_column_time = FALSE,  #TRUE
	                   exclusion_radius = 0,
	                   theta = theta.SE)
	


# make predictions with diversity = + 0.025 SD
	pred.SE <- c(1,NROW(block.SE))
	lib.SE <- pred.SE + NROW(block.SE)
  block.temp1 <- block.SE %>%
	mutate(Diversity_t = Diversity_t +  0.5*dDiversity) %>%
	bind_rows(block.SE)

	out1 <- block_lnlp(block=block.temp1,
	lib = lib.SE,
	pred = pred.SE,
	method = 's-map',
	tp = 0,
	#num_neighbors = 0,
	columns = 1+(1:E.SE),
	target_column = 1,
	stats_only = FALSE,
	first_column_time = FALSE,  #TRUE
	exclusion_radius = 0,
	theta = theta.SE)
  
 # [[1]]$model_output[1:NROW(block.SE),]

	

# make predictions with diversity = divesrity - 0.025 SD
	pred.SE <- c(1,NROW(block.SE))
	lib.SE <- pred.SE + NROW(block.SE)
  block.temp2 <- block.SE %>%
	mutate(Diversity_t = Diversity_t - 0.5*dDiversity) %>%   #abs(Diversity_t*0.05)
	bind_rows(block.SE)
 
	out2 <- block_lnlp(block=block.temp2,
	lib = lib.SE,
	pred = pred.SE,
	method = 's-map',
	tp = 0,
	#num_neighbors = 0,
	columns = 1+(1:E.SE),
	target_column = 1,
	stats_only = FALSE,
	first_column_time = FALSE,  #TRUE
	exclusion_radius = 0,
	theta = theta.SE
  )
  


save(out0,out1,out2,theta.SE,df.in,df.in.SE, block.SE,file = paste(site,'_SE_',indmat[i,1],'_',indmat[i,2],'_scale','.RData',sep = ""))

#d.pred_Diversity <-  d.pred /(0.1*sd(df.in$Diversity,na.rm=TRUE))

#ccm_results <- ccm_results %>% bind_rows(data.frame(Cause=indmat[i,1],Effects=indmat[i,2],norm_method = norm_method,  pred="10%",E = E.SE, theta=theta.SE,mean_d_norm = mean(d.pred.norm), mean_d=mean(d.pred) ))

}

#del variables 

# end for ST9




# load data and run analysis for L4
site = 'L4' 
dat_L4 <- read.csv(paste(mainDir,'/Data/','L4_Diversity_RUE.csv',sep = "")) # read in plot-level data with raw vars
dat_L4$date = as.POSIXlt(dat_L4$Date, tz = "GMT")

# selecting FAD2, FDc, FRic, H, and RUEs
ye.dat.L4=dat_L4[,c(10,2:4,6:9)]
ye.dat = ye.dat.L4
testvb=colnames(ye.dat[c(2:8)])
nvb=length(testvb)
cause_name = testvb[c(1:4)]
effect_name = testvb[c(5:7)]

indmat =matrix(0,length(cause_name)*length(effect_name),2);colnames(indmat)=c('Effect','Cause')
indmat[,1]=rep(effect_name,each=length(cause_name))
indmat[,2]=rep(cause_name,length(effect_name))

 


# Scenario Exploration
# Parameters
#ccm_results = NULL
 

for(i in 1:nrow(indmat)){
 
 #for each RUE
  df.in = data.frame (date = ye.dat$date, RUE = ye.dat[,indmat[i,1]], Diversity = ye.dat[,indmat[i,2]])
 
 #normilize the input
  df.in.SE = data.frame (date = ye.dat$date, RUE = scale(ye.dat[,indmat[i,1]]), Diversity = scale(ye.dat[,indmat[i,2]])) 

	idx <- is.finite(df.in.SE$RUE) & is.finite(df.in.SE$Diversity)
	df.in.SE <- df.in.SE[idx,]
  df.in.non_zero = df.in[idx,]

if (site == 'ST9'){
E.SE = E.ST9[i] } else {
E.SE = E.L4[i]
}

  block.SE <- make_block(df.in.SE[,c('RUE','Diversity')],c(rep(1,E.SE),2),c(tp=tp.SE,0:-(E.SE-2),0)	) %>%
	as.data.frame()
#	block.SE <- data.frame(time = df.in.SE$date, block.SE)

  # test the best theta
        smapT.test <- block_lnlp(block.SE,
                               method = "s-map",
                               num_neighbors = 0,
                               save_smap_coefficients = F,
                               target_column = 1,
                               columns = 1+(1:E.SE),
                               first_column_time = F,
                               theta = theta.test.range,
                               exclusion_radius = 0,
                               silent = T)

       theta.SE <- smapT.test[which.max(smapT.test$rho), "theta"]


	# make predictions with diversity no change
	pred.SE <- c(1,NROW(block.SE))
	lib.SE <- pred.SE + NROW(block.SE)
	block.temp0 <- block.SE %>%
	  mutate(Diversity_t = Diversity_t) %>%
	  bind_rows(block.SE)

	out0 <- block_lnlp(block=block.temp0,
	                   lib = lib.SE,
	                   pred = pred.SE,
	                   method = 's-map',
	                   tp = 0,
	                   #num_neighbors = 0,
	                   columns = 1+(1:E.SE),
	                   target_column = 1,
	                   stats_only = FALSE,
	                   first_column_time = FALSE,  #TRUE
	                   exclusion_radius = 0,
	                   theta = theta.SE)
	


# make predictions with diversity = divesrity + 0.05
	pred.SE <- c(1,NROW(block.SE))
	lib.SE <- pred.SE + NROW(block.SE)
  block.temp1 <- block.SE %>%
	mutate(Diversity_t = Diversity_t +  0.5*dDiversity) %>%
	bind_rows(block.SE)
 
	out1 <- block_lnlp(block=block.temp1,
	lib = lib.SE,
	pred = pred.SE,
	method = 's-map',
	tp = 0,
	#num_neighbors = 0,
	columns = 1+(1:E.SE),
	target_column = 1,
	stats_only = FALSE,
	first_column_time = FALSE,  #TRUE
	exclusion_radius = 0,
	theta = theta.SE)
  
 # [[1]]$model_output[1:NROW(block.SE),]

	

# make predictions with diversity = divesrity - 0.05
	pred.SE <- c(1,NROW(block.SE))
	lib.SE <- pred.SE + NROW(block.SE)
	block.temp2 <- block.SE %>%
	mutate(Diversity_t = Diversity_t - 0.5*dDiversity) %>%
	bind_rows(block.SE)
 
	out2 <- block_lnlp(block=block.temp2,
	lib = lib.SE,
	pred = pred.SE,
	method = 's-map',
	tp = 0,
	#num_neighbors = 0,
	columns = 1+(1:E.SE),
	target_column = 1,
	stats_only = FALSE,
	first_column_time = FALSE,  #TRUE
	exclusion_radius = 0,
	theta = theta.SE
  )
  
  

save(out0,out1,out2,theta.SE,df.in,df.in.SE,block.SE,file = paste(site,'_SE_',indmat[i,1],'_',indmat[i,2],'_scale','.RData',sep = ""))

#d.pred_Diversity <-  d.pred /(0.1*sd(df.in$Diversity,na.rm=TRUE))

#ccm_results <- ccm_results %>% bind_rows(data.frame(Cause=indmat[i,1],Effects=indmat[i,2],norm_method = norm_method,  pred="10%",E = E.SE, theta=theta.SE,mean_d_norm = mean(d.pred.norm), mean_d=mean(d.pred) ))

}	


#write.csv(ccm_results , "SE_L4_BestE_by_0.1.csv")
# end for the scenaro analysis

write.csv(dDiversity , "dDiversity.csv")

#Begining ploting Fig 3 & 4

ccm_results = NULL
corr_results = NULL
labels_results = NULL

load(paste(mainDir,'/Data/','indmat.rData',sep = ""))
indmat.st9 = cbind(indmat.st9,'ST9')
indmat.L4 = cbind(indmat.L4,'L4')
indmat1 = rbind (indmat.st9, indmat.L4)
colnames(indmat1)=c('Effect','Cause','Site')

indmat1 = indmat1[c(-12,-13,-17,-18,-19,-20),]
rm(out0,out1,out2,theta.SE,df.in,df.in.SE,block.SE)
for(i in 1:nrow(indmat1)){

load(file = paste(indmat1[i,3],'_SE_',indmat1[i,1],'_',indmat1[i,2],'_scale','.RData',sep = ""))

#normalized values
dRUE = (out1$model_output[[which.max(out1$rho)]]$pred - out2$model_output[[which.max(out2$rho)]]$pred)
dRUE_dDiversity = dRUE/dDiversity

tmp.cor = cor.test(df.in.SE$Diversity,dRUE_dDiversity) 

corr_results <- corr_results %>% bind_rows(data.frame(Site=indmat1[i,3],Effect=indmat1[i,1],Cause=indmat1[i,2],mean_dRUE_dDiversity=mean(dRUE_dDiversity,na.rm=TRUE),r_value=as.vector(tmp.cor$estimate),p_value=tmp.cor$p.value))

ccm_results <- ccm_results %>% bind_rows(data.frame(date = df.in.SE$date,RUE=df.in.SE$RUE,Diversity=df.in.SE$Diversity, Diversity.raw=df.in.SE$Diversity*sd(df.in$Diversity,na.rm=TRUE)+mean(df.in$Diversity,na.rm=TRUE), Cause=indmat1[i,2],Effects=indmat1[i,1],site = indmat1[i,3],   dRUE=dRUE, dRUE_dDiversity = dRUE/dDiversity,dRUE_dDiversity.raw = (dRUE*sd(df.in$RUE,na.rm=TRUE))/(dDiversity*sd(df.in$Diversity,na.rm=TRUE)), Lab = 15-i))

labels_results <- labels_results  %>% bind_rows(data.frame(Lab = 15-i,Cause=indmat1[i,1],Effects=indmat1[i,2],site = indmat1[i,3]))

rm(out0,out1,out2,theta.SE,df.in,df.in.SE,block.SE)
}

#preparing data for ST9
#     Effect     Cause  Site 
# [1,] "RUE_DIN"  "FAD2" "ST9"
# [2,] "RUE_DIN"  "FDc"  "ST9"
# [3,] "RUE_DIN"  "FRic" "ST9"
# [4,] "RUE_DIN"  "H"    "ST9"
# [5,] "RUE_PO4P" "FAD2" "ST9"
# [6,] "RUE_PO4P" "FDc"  "ST9"
# [7,] "RUE_PO4P" "FRic" "ST9"
# [8,] "RUE_PO4P" "H"    "ST9"
# [9,] "RUE_DSi"  "FAD2" "L4" 
#[10,] "RUE_DSi"  "FDc"  "L4" 
#[11,] "RUE_DSi"  "FRic" "L4" 
#[12,] "RUE_PO4P" "FDc"  "L4" 
#[13,] "RUE_PO4P" "FRic" "L4" 
#[14,] "RUE_PO4P" "H"    "L4"



ST9.in.RUE_DIN_FAD2 <- ccm_results %>%
filter(Effects == 'RUE_DIN') %>% 
filter(Cause == 'FAD2') %>% 
filter(site == 'ST9')

ST9.in.RUE_DIN_FDc <- ccm_results %>%
filter(Effects == 'RUE_DIN') %>% 
filter(Cause == 'FDc') %>% 
filter(site == 'ST9')

ST9.in.RUE_DIN_FRic <- ccm_results %>%
filter(Effects == 'RUE_DIN') %>% 
filter(Cause == 'FRic') %>% 
filter(site == 'ST9')

ST9.in.RUE_DIN_H <- ccm_results %>%
filter(Effects == 'RUE_DIN') %>% 
filter(Cause == 'H') %>% 
filter(site == 'ST9')

ST9.in.RUE_PO4P_FAD2 <- ccm_results %>%
filter(Effects == 'RUE_PO4P') %>% 
filter(Cause == 'FAD2') %>% 
filter(site == 'ST9')

ST9.in.RUE_PO4P_FDc <- ccm_results %>%
filter(Effects == 'RUE_PO4P') %>% 
filter(Cause == 'FDc') %>% 
filter(site == 'ST9')

ST9.in.RUE_PO4P_FRic <- ccm_results %>%
filter(Effects == 'RUE_PO4P') %>% 
filter(Cause == 'FRic') %>% 
filter(site == 'ST9')

ST9.in.RUE_PO4P_H <- ccm_results %>%
filter(Effects == 'RUE_PO4P') %>% 
filter(Cause == 'H') %>% 
filter(site == 'ST9')


#preparing data for L4

L4.in.RUE_DSi_FAD2 <- ccm_results %>%
filter(Effects == 'RUE_DSi') %>% 
filter(Cause == 'FAD2') %>% 
filter(site == 'L4')



L4.in.RUE_DSi_FDc <- ccm_results %>%
filter(Effects == 'RUE_DSi') %>% 
filter(Cause == 'FDc') %>% 
filter(site == 'L4')

L4.in.RUE_DSi_FRic <- ccm_results %>%
filter(Effects == 'RUE_DSi') %>% 
filter(Cause == 'FRic') %>% 
filter(site == 'L4')


L4.in.RUE_PO4P_FDc <- ccm_results %>%
filter(Effects == 'RUE_PO4P') %>% 
filter(Cause == 'FDc') %>% 
filter(site == 'L4')

L4.in.RUE_PO4P_FRic <- ccm_results %>%
filter(Effects == 'RUE_PO4P') %>% 
filter(Cause == 'FRic') %>% 
filter(site == 'L4')

L4.in.RUE_PO4P_H <- ccm_results %>%
filter(Effects == 'RUE_PO4P') %>% 
filter(Cause == 'H') %>% 
filter(site == 'L4')






#plot for ST9

dev.new(width=8, height=5)
##par(mfrow = c(4,2))
#par(mfrow = c(4,2),mai=c(0.5,0.2,0.2,0.2),oma=c(2,4,0.5,0.5))
#par(mfrow = c(4,2))
par(mfrow = c(2,4),mai=c(0.5,0.2,0.2,0.2),oma=c(2,5,0.5,0.5),mgp=c(2,1,0))

par(cex = 0.8)
with(ST9.in.RUE_DIN_FAD2, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FAD2",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40') + abline(lm(dRUE_dDiversity~Diversity),lty=1,lwd=2,col="red")+mtext("A",side=3,adj=-0.14,line=-1,cex = 0.8)+mtext(expression('RUE'[N]*'/Z'), side = 2, line = 2,cex = 0.8))
with(ST9.in.RUE_DIN_FDc, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FDc",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+abline(lm(dRUE_dDiversity~Diversity),lty=1,lwd=2,col="red")+mtext("B",side=3,adj=-0.14,line=-1,cex = 0.8))
with(ST9.in.RUE_DIN_FRic, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FRic",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+mtext("C",side=3,adj=-0.14,line=-1,cex = 0.8))
with(ST9.in.RUE_DIN_H, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="H",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+mtext("D",side=3,adj=-0.14,line=-1,cex = 0.8))


with(ST9.in.RUE_PO4P_FAD2, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FAD2",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+mtext("E",side=3,adj=-0.14,line=-1,cex = 0.8)+mtext(expression('RUE'[P]*'/Z'), side = 2, line = 2,cex = 0.8)) 
with(ST9.in.RUE_PO4P_FDc, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FDc",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+abline(lm(dRUE_dDiversity~Diversity),lty=1,lwd=2,col="red")+mtext("F",side=3,adj=-0.14,line=-1,cex = 0.8))
with(ST9.in.RUE_PO4P_FRic, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FRic",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+mtext("G",side=3,adj=-0.14,line=-1,cex = 0.8))
with(ST9.in.RUE_PO4P_H, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="H",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+mtext("H",side=3,adj=-0.14,line=-1,cex = 0.8)) 


mtext('       Effects of diversity on resource use efficiency (RUE)', side = 2, outer = TRUE, line =2.6,cex = 0.9)
            



#plot for figure 4

dev.new(width=8, height=5)
##par(mfrow = c(4,2))
#par(mfrow = c(4,2),mai=c(0.5,0.2,0.2,0.2),oma=c(2,4,0.5,0.5))
#par(mfrow = c(4,2))
par(mfrow = c(2,4),mai=c(0.5,0.2,0.2,0.2),oma=c(2,5,0.5,0.5),mgp=c(2,1,0))
par(cex = 0.8)
with(L4.in.RUE_PO4P_FDc, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FDc",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+abline(lm(dRUE_dDiversity~Diversity),lty=1,lwd=2,col="red")+mtext("A",side=3,adj=-0.14,line=-1,cex = 0.8)+mtext(expression('RUE'[P]*'/Z'), side = 2, line = 2,cex = 0.8) )
with(L4.in.RUE_PO4P_FRic, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FRic",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+abline(lm(dRUE_dDiversity~Diversity),lty=1,lwd=2,col="red")+mtext("B",side=3,adj=-0.14,line=-1,cex = 0.8))
with(L4.in.RUE_PO4P_H, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="H",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+mtext("C",side=3,adj=-0.14,line=-1,cex = 0.8))
plot.new()

with(L4.in.RUE_DSi_FDc, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FDc",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+abline(lm(dRUE_dDiversity~Diversity),lty=1,lwd=2,col="red")+mtext("D",side=3,adj=-0.14,line=-1,cex = 0.8)+mtext(expression('RUE'[Si]*'/Z'), side = 2, line = 2,cex = 0.8))
with(L4.in.RUE_DSi_FRic, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FRic",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+abline(lm(dRUE_dDiversity~Diversity),lty=1,lwd=2,col="red")+mtext("E",side=3,adj=-0.14,line=-1,cex = 0.8))
with(L4.in.RUE_DSi_FAD2, plot(Diversity,dRUE_dDiversity, pch=1,col=4,xlab="FAD2",ylab="") +  abline(h=mean(dRUE_dDiversity,na.rm=TRUE),lty=2,lwd=2,col='grey40')+abline(lm(dRUE_dDiversity~Diversity),lty=1,lwd=2,col="red")+mtext("F",side=3,adj=-0.14,line=-1,cex = 0.8))
plot.new()

mtext('       Effects of diversity on resource use efficiency (RUE)', side = 2, outer = TRUE, line =2.6,cex = 0.9)
            



