#Ploting Fig. S4 Results of CCMs tests in the Lake Kasumigaura (ST9) with a shorter time series length (library size =132, same as the total length of L4 dataset) 

library('rEDM')
library('dplyr')
library('tidyr')


# load functions
make_block <- function(data,cols,delays,lib=c(1,NROW(data))){
	lib <- matrix(lib,ncol = 2)
	data <- as.matrix(data)
	ncol <- length(cols)
	nrow <- dim(data)[1]
	block <- array(NA,dim = c(nrow,ncol))
	colnames(block) <- 1:ncol
	
	for (i in 1:ncol){
		I <- 1:nrow
		I_delay <- intersect(I,I+delays[i])
		block[I_delay-delays[i],i] <- data[I_delay,cols[i]]
		if (delays[i] < 0){
			# remove data points that fall at start of lib segments
			block[lib[,1] - (0:(delays[i]+1)),i] <- NA
			colnames(block)[i] <- paste(colnames(data)[cols[i]],'_t-',abs(delays[i]),sep="")
			} else if (delays[i] > 0) {
			# remove data points that fall at end of lib segments
			block[lib[,2] - (0:(delays[i]+1)),i] <- NA
			colnames(block)[i] <- paste(colnames(data)[cols[i]],'_t+',abs(delays[i]),sep="")
			} else {
			colnames(block)[i] <- paste(colnames(data)[cols[i]],'_t',sep="")
		}
	}
	return(block)
}

#Seasonality and Surrogates
yearday_anom <- function(t,x){
	# t: date formatted with POSIXt
	# x: time-series values to compute seasonal mean and anomaly
	doy <- as.numeric(strftime(t, format = "%j"))
	I_use <- which(!is.na(x))
	# create time indices to use for smoothing, replicating data to "wrap around"
	doy_sm <- rep(doy[I_use],3) + rep(c(-366,0,366),each=length(I_use))
	x_sm <- rep(x[I_use],3)
	xsp <- smooth.spline(doy_sm, y = x_sm, w = NULL, spar = 0.8, cv = NA,
	all.knots = TRUE,keep.data = TRUE, df.offset = 0)
	xbar <- data.frame(t=t,doy=doy) %>%
	left_join(data.frame(doy=xsp$x,xbar=xsp$y),by='doy') %>%
	select(xbar)
	out = data.frame(t=t,mean=xbar,anomaly=(x - xbar))
	names(out) <- c('date','mean','anomaly')
	return(out)
}


# lag dataset (lag=0~3)
####### Function for generating pairwise lag series 
laf=function(x,y,lagf){
  n <- NROW(x)
  x.t=x;y.t=y
  if(lagf<=0){x.t=x.t[(1-lagf):n];y.t=y.t[1:(n+lagf)]} # if lagf<0, y is leading
  #if(lagf<=0){x.t=c(x.t,rep(NA,abs(lagf)));y.t=c(rep(NA,abs(lagf)),y.t)}
  
  if(lagf>0){x.t=x.t[1:(n-lagf)];y.t=y.t[(1+lagf):n]}  # if lagf>0, x is leading 
 #if(lagf>0){x.t=c(rep(NA,abs(lagf)), x.t);y.t=c(y.t,rep(NA,abs(lagf)))}  # if lagf>0, x is leading           
  return(cbind(x.t,y.t))
}

make_pred_nozero <- function(time_series,E){
	I_zero_strings <- which(time_series==0)
	I_zero_strings <- Reduce(intersect, lapply((0:E),function(offset) I_zero_strings-offset))
	I_zero_strings <- c(0,I_zero_strings,NROW(df.in)) # for convenience in next step
	N_zero_strings <- length(I_zero_strings)
	lib_nozeroes <- cbind(I_zero_strings[1:(N_zero_strings-1)]+1,I_zero_strings[2:(N_zero_strings)]-1)
	lib_out <- lib_nozeroes[which(lib_nozeroes[,2] > lib_nozeroes[,1]),]
	return(lib_out)
	}





#Set working directory
mainDir <- getwd()
subDir <- 'ST9_CCM_Short_Lib' 
#setwd(paste(mainDir,'/ST9_CCM_tests',sep = ""))
if (file.exists(subDir)){
    setwd(file.path(mainDir, subDir))
} else {
    dir.create(file.path(mainDir, subDir))
    setwd(file.path(mainDir, subDir))
}



#load data for ST9
dat <- read.csv(paste(mainDir,'/Data/','ST9_Diversity_RUE.csv',sep = ""))
dat$date = as.POSIXlt(dat$Date, tz = "GMT")
# selecting FAD2, FDc, FRic, H, and RUEs
ye.dat=dat[,c(9,2:4,6:8)]
head(ye.dat)


testvb=colnames(ye.dat[c(2:7)])
nvb=length(testvb)
cause_name = testvb[c(1:4)]
effect_name = testvb[c(5:6)]

indmat =matrix(0,length(cause_name)*length(effect_name),2);colnames(indmat)=c('Effect','Cause')
indmat[,1]=rep(effect_name,each=length(cause_name))
indmat[,2]=rep(cause_name,length(effect_name))
lag.direct= c(-5,-4,0,-6,-2,-2,0,-2)
lag.surr= c(-1,-1,-3,-1,-2,-1,-4,-4)

#optimal E based on FNN Fig S1
E.mat = c(5,5,5,5,7,7,7,7)


ccm_results = data.frame()


for(i in 1:nrow(indmat)){
 
 #for each RUE
 df.in = data.frame (date = ye.dat$date, RUE = ye.dat[,indmat[i,1]], Diversity = ye.dat[,indmat[i,2]])
 E_star= E.mat[i]


 set.seed(599213) 
 

out_diversity <- yearday_anom(df.in$date,df.in$Diversity)
Diversity.bar <- out_diversity$mean
Diversity.tilde <- out_diversity$anomaly

#plot(df.in$date,df.in$Diversity)
#lines(df.in$date,Diversity.bar,col='red')

#cor.test(df.in$Diversity, Diversity.bar, method="spearman")



out_rue <- yearday_anom(df.in$date,df.in$RUE)
RUE.bar <- out_rue$mean
RUE.tilde <- out_rue$anomaly
#plot(df.in$date,df.in$RUE)
#lines(df.in$date,RUE.bar,col='red')
#cor.test(df.in$RUE, RUE.bar, method="spearman")



#2.c Calculating seasonal surrogates for RUE and Diversity
Diversity.surrs <- do.call(cbind,
lapply(1:500, function(i) {
	I_na <- is.na(Diversity.tilde)
	out <- Diversity.bar
	out[I_na] <- NA
	out[!I_na] <- out[!I_na] + sample(Diversity.tilde[!I_na],sum(!I_na),replace = FALSE)
	return(out)
})
)



#plot(df.in$date,df.in$Diversity,type='l',col='blue',xlab='date',ylab='Diversity')
#lines(df.in$date,Diversity.surrs[,1],col='red')
#legend( x="topright",
#legend=c("Observed","Seasonal Surrogate"),
#col=c("blue","red"), lwd=1, lty=c(1,1),bg='white')

#cor.test(df.in$Diversity, Diversity.surrs[,1], method="spearman")
#plot(df.in$date,df.in$Diversity)
#lines(df.in$date,Diversity.surrs[,1],col='red')


# Surrgae for RUE
RUE.surrs <- do.call(cbind,
lapply(1:500, function(i) {
	I_na <- is.na(RUE.tilde)
	out <- RUE.bar
	out[I_na] <- NA
	out[!I_na] <- out[!I_na] + sample(RUE.tilde[!I_na],sum(!I_na),replace = FALSE)
	return(out)
})
)


#3.CCM

	
 
  	#3.a Determine optimal E for direct CCM
# for (lags in -6:0) {  # lag = -12 means  
  dat_temp <- select(df.in,RUE,Diversity)
  
  block_temp = data.frame(laf(dat_temp[,1],dat_temp[,2],lagf=lag.direct[i]))
#  block_temp = data.frame(laf(dat_temp[,1],dat_temp[,2],lagf=lags))
  colnames(block_temp) = c("RUE","Diversity")
 
   
  
	lib_ccm <- c(1,NROW(block_temp))

	#out.temp <- do.call(
#	rbind,
#	lapply(1:24, function(E_i){
#	pred_ccm <- make_pred_nozero(block_temp$RUE,E_i)
#	ccm(block=block_temp, 
#	E=E_i,
#	lib=lib_ccm,
#  pred=pred_ccm,
#	lib_sizes = NROW(block_temp),
#	exclusion_radius=0,
#	random_libs = FALSE,
#	num_sample=1,
#	tp = 0,
#	lib_column = 1,
#	target_column = 2)
#	})
#	)
#	E_star <- out.temp$E[which.max(out.temp$rho)]	
#  
  	
	
 	#3.b Calculate CCM for real data
	pred_ccm <- make_pred_nozero(block_temp$RUE,E_star)
	df.out.ccm <- ccm(block=block_temp,
	E=E_star,
	lib=lib_ccm,
	pred = pred_ccm,
  lib_column = 1,
  target_column = 2,
	lib_sizes = 132,
	exclusion_radius=0,
	random_libs = TRUE,
	num_sample=50,
	tp = 0)
 
  save(df.out.ccm, file = paste('ST9_direct',indmat[i,1],'_xmap_',indmat[i,2],'_lags=',lag.direct[i],'.RData',sep = ""))
   

	
	#3.c Calculate null distributions for CCM with surrogates  for RUE and diversity 
	
	df.out.ccm.surr <- data.frame()
	for (i_surr in 1:dim(Diversity.surrs)[2]){
	dat_temp <- data.frame(RUE=RUE.surrs[,i_surr],Diversity=Diversity.surrs[,i_surr])
 
  block_temp = data.frame(laf(dat_temp[,1],dat_temp[,2],lagf=lag.surr[i]))
#  block_temp = data.frame(laf(dat_temp[,1],dat_temp[,2],lagf=lags))
  colnames(block_temp) = c("RUE","Diversity")
 
  lib_ccm <- c(1,NROW(block_temp))

#	out.temp <- do.call(
#	rbind,
#	lapply(1:24, function(E_i){
#	pred_ccm <- make_pred_nozero(block_temp$RUE,E_i)
#	ccm(block=block_temp,
#	E=E_i,
#	lib=lib_ccm,
#	pred=pred_ccm,
#	lib_sizes = NROW(block_temp),
#	exclusion_radius=0,
#	random_libs = FALSE,
#	num_sample=1,
#	tp = 0,
#	lib_column = 1,
#	target_column = 2)
#	})
#	)
#	E_star <- out.temp$E[which.max(out.temp$rho)]
 
	pred_ccm <- make_pred_nozero(block_temp$RUE,E_star)
	out.temp <- ccm(block=block_temp,
	E=E_star,
	lib=lib_ccm,
	pred = pred_ccm,
	lib_sizes = 132,
	exclusion_radius=0,
	random_libs = TRUE,
	num_sample=50,
	tp = 0,
  lib_column = 1,
	target_column = 2)
	df.out.ccm.surr <- df.out.ccm.surr %>% bind_rows(out.temp)
	} # for i_surr

   save(df.out.ccm.surr, file = paste('ST9_surr',indmat[i,1],'_xmap_',indmat[i,2],'_lags=',lag.surr[i],'.RData',sep = ""))
  
  #remove 0 in df.out.ccm.surr and df.out.ccm
  df.out.ccm.surr1 = df.out.ccm.surr
  df.out.ccm.surr1[df.out.ccm.surr1[,'rho']<0,'rho']=0
  
  df.out.ccm1 = df.out.ccm
  df.out.ccm1[df.out.ccm1[,'rho']<0,'rho']=0
  

 # save 
  ccm_results <- ccm_results %>% bind_rows(data.frame(Cause=indmat[i,1],Effects=indmat[i,2],Lag.direct = lag.direct[i], Direct_rho1=df.out.ccm1$rho, Lag.surr = lag.surr[i],Mean_surr1_rho = ccm_means(df.out.ccm.surr1)$rho) )
  
cat(i, "in", nrow(indmat),",  ",indmat[i,1],"xmap",indmat[i,2],". lags = ","\n")


# } end lags
}
save(ccm_results, file = "ST9_ccm_results.RData") 
write.csv(ccm_results, file = "Table_S1.csv")
##
 

#



#load surr data for RUEN~Diversity
load('ST9_surrRUE_DIN_xmap_FAD2_lags=-1.RData')
df.out.ccm.surr$rho[which(df.out.ccm.surr$rho < 0)] = 0
N_xmap_FAD2.surr = df.out.ccm.surr
rm(df.out.ccm.surr)

load('ST9_surrRUE_DIN_xmap_FDc_lags=-1.RData')
df.out.ccm.surr$rho[which(df.out.ccm.surr$rho < 0)] = 0
N_xmap_FDc.surr = df.out.ccm.surr
rm(df.out.ccm.surr)

load('ST9_surrRUE_DIN_xmap_FRic_lags=-3.RData')
df.out.ccm.surr$rho[which(df.out.ccm.surr$rho < 0)] = 0
N_xmap_FRic.surr = df.out.ccm.surr
rm(df.out.ccm.surr)

load('ST9_surrRUE_DIN_xmap_H_lags=-1.RData')
df.out.ccm.surr$rho[which(df.out.ccm.surr$rho < 0)] = 0
N_xmap_H.surr = df.out.ccm.surr
rm(df.out.ccm.surr)

#load dirct data
load('ST9_directRUE_DIN_xmap_FAD2_lags=-5.RData')
df.out.ccm$rho[which(df.out.ccm$rho < 0)] = 0
N_xmap_FAD2.direct = df.out.ccm
rm(df.out.ccm)

load('ST9_directRUE_DIN_xmap_FDc_lags=-4.RData')
df.out.ccm$rho[which(df.out.ccm$rho < 0)] = 0
N_xmap_FDc.direct = df.out.ccm
rm(df.out.ccm)


load('ST9_directRUE_DIN_xmap_FRic_lags=0.RData')
df.out.ccm$rho[which(df.out.ccm$rho < 0)] = 0
N_xmap_FRic.direct = df.out.ccm
rm(df.out.ccm)

load('ST9_directRUE_DIN_xmap_H_lags=-6.RData')
df.out.ccm$rho[which(df.out.ccm$rho < 0)] = 0
N_xmap_H.direct = df.out.ccm
rm(df.out.ccm)


#load surr data for P
load('ST9_surrRUE_PO4P_xmap_FAD2_lags=-2.RData')
df.out.ccm.surr$rho[which(df.out.ccm.surr$rho < 0)] = 0
P_xmap_FAD2.surr = df.out.ccm.surr
rm(df.out.ccm.surr)

load('ST9_surrRUE_PO4P_xmap_FDc_lags=-1.RData')
df.out.ccm.surr$rho[which(df.out.ccm.surr$rho < 0)] = 0
P_xmap_FDc.surr = df.out.ccm.surr
rm(df.out.ccm.surr)

load('ST9_surrRUE_PO4P_xmap_FRic_lags=-4.RData')
df.out.ccm.surr$rho[which(df.out.ccm.surr$rho < 0)] = 0
P_xmap_FRic.surr = df.out.ccm.surr
rm(df.out.ccm.surr)

load('ST9_surrRUE_PO4P_xmap_H_lags=-4.RData')
df.out.ccm.surr$rho[which(df.out.ccm.surr$rho < 0)] = 0
P_xmap_H.surr = df.out.ccm.surr
rm(df.out.ccm.surr)

#load dirct data
load('ST9_directRUE_PO4P_xmap_FAD2_lags=-2.RData')
df.out.ccm$rho[which(df.out.ccm$rho < 0)] = 0
P_xmap_FAD2.direct = df.out.ccm
rm(df.out.ccm)

load('ST9_directRUE_PO4P_xmap_FDc_lags=-2.RData')
df.out.ccm$rho[which(df.out.ccm$rho < 0)] = 0
P_xmap_FDc.direct = df.out.ccm
rm(df.out.ccm)



load('ST9_directRUE_PO4P_xmap_FRic_lags=0.RData')
df.out.ccm$rho[which(df.out.ccm$rho < 0)] = 0
P_xmap_FRic.direct = df.out.ccm
rm(df.out.ccm)

load('ST9_directRUE_PO4P_xmap_H_lags=-2.RData')
df.out.ccm$rho[which(df.out.ccm$rho < 0)] = 0
P_xmap_H.direct = df.out.ccm
rm(df.out.ccm)


# calculating the p-values
(sum(mean(N_xmap_FAD2.direct$rho) < N_xmap_FAD2.surr$rho) + 1) / (length(N_xmap_FAD2.surr$rho) + 1)
(sum(mean(N_xmap_FDc.direct$rho) < N_xmap_FDc.surr$rho) + 1) / (length(N_xmap_FDc.surr$rho) + 1)
(sum(mean(N_xmap_FRic.direct$rho) < N_xmap_FRic.surr$rho) + 1) / (length(N_xmap_FRic.surr$rho) + 1)
(sum(mean(N_xmap_H.direct$rho) < N_xmap_H.surr$rho) + 1) / (length(N_xmap_H.surr$rho) + 1)

(sum(mean(P_xmap_FAD2.direct$rho) < P_xmap_FAD2.surr$rho) + 1) / (length(P_xmap_FAD2.surr$rho) + 1)
(sum(mean(P_xmap_FDc.direct$rho) < P_xmap_FDc.surr$rho) + 1) / (length(P_xmap_FDc.surr$rho) + 1)
(sum(mean(P_xmap_FRic.direct$rho) < P_xmap_FRic.surr$rho) + 1) / (length(P_xmap_FRic.surr$rho) + 1)
(sum(mean(P_xmap_H.direct$rho) < P_xmap_H.surr$rho) + 1) / (length(P_xmap_H.surr$rho) + 1)


#combine data
#df.in = data.frame (rho= N_xmap_FAD1.surr$rho, diversity = 'FAD2')
df.in.N = rbind(data.frame (rho= N_xmap_FAD2.surr$rho, diversity = 'FAD2'),data.frame (rho= N_xmap_FDc.surr$rho, diversity = 'FDc'),data.frame (rho= N_xmap_FRic.surr$rho, diversity = 'FRic'),data.frame (rho= N_xmap_H.surr$rho, diversity = 'H'))

df.in.P = rbind(data.frame (rho= P_xmap_FAD2.surr$rho, diversity = 'FAD2'),data.frame (rho= P_xmap_FDc.surr$rho, diversity = 'FDc'),data.frame (rho= P_xmap_FRic.surr$rho, diversity = 'FRic'),data.frame (rho= P_xmap_H.surr$rho, diversity = 'H'))




## boxplot for ST9 CCM with short lib 

X11(7, 15)
#par(mar = c(4, 4, 1, 1), mgp = c(2.5, 1, 0))
par(mfrow = c(3, 1),mar = c(4, 4, 1, 1))
#x11(width=5, height=3)
boxplot(rho ~ diversity, data = df.in.N,cex.axis=1.2,ylim=c(-0.005,0.82),cex=1.2,horizontal = TRUE)
points(mean(N_xmap_FAD2.direct$rho),1,pch=19,col='red',cex=4,lwd=2)
points(mean(N_xmap_FDc.direct$rho),2,pch=19,col='red',cex=4,lwd=2)
points(mean(N_xmap_FRic.direct$rho),3,pch=19,col='red',cex=4,lwd=2)
points(mean(N_xmap_H.direct$rho),4,pch=19,col='red',cex=4,lwd=2)
#rm(list=ls())


boxplot(rho ~ diversity, data = df.in.P,cex.axis=1.2,ylim=c(-0.005,0.82),cex=1.2,horizontal = TRUE,cex.lab=1.4,xlab="Cross map skill")
points(mean(P_xmap_FAD2.direct$rho),1,pch=19,col='red',cex=4,lwd=2)
points(mean(P_xmap_FDc.direct$rho),2,pch=19,col='red',cex=4,lwd=2)
points(mean(P_xmap_FRic.direct$rho),3,pch=19,col='red',cex=4,lwd=2)
points(mean(P_xmap_H.direct$rho),4,pch=19,col='red',cex=4,lwd=2)



	